@@ -6,7 +6,7 @@ from __future__ import annotations
 import ast
 import sys
 from contextlib import suppress
-from typing import TYPE_CHECKING, Any, Final
+from typing import TYPE_CHECKING, Final
 
 from griffe._internal.agents.nodes.assignments import get_instance_names, get_names
 from griffe._internal.agents.nodes.ast import (
@@ -48,7 +48,7 @@ from griffe._internal.models import (
 if TYPE_CHECKING:
     from pathlib import Path
 
-    from griffe._internal.docstrings.parsers import DocstringStyle
+    from griffe._internal.docstrings.parsers import DocstringOptions, DocstringStyle
     from griffe._internal.enumerations import Parser
 
 
@@ -84,7 +84,7 @@ def visit(
     extensions: Extensions | None = None,
     parent: Module | None = None,
     docstring_parser: DocstringStyle | Parser | None = None,
-    docstring_options: dict[str, Any] | None = None,
+    docstring_options: DocstringOptions | None = None,
     lines_collection: LinesCollection | None = None,
     modules_collection: ModulesCollection | None = None,
 ) -> Module:
@@ -107,7 +107,7 @@ def visit(
         extensions: The extensions to use when visiting the AST.
         parent: The optional parent of this module.
         docstring_parser: The docstring parser to use. By default, no parsing is done.
-        docstring_options: Additional docstring parsing options.
+        docstring_options: Docstring parsing options.
         lines_collection: A collection of source code lines.
         modules_collection: A collection of modules.
 
@@ -141,7 +141,7 @@ class Visitor:
         extensions: Extensions,
         parent: Module | None = None,
         docstring_parser: DocstringStyle | Parser | None = None,
-        docstring_options: dict[str, Any] | None = None,
+        docstring_options: DocstringOptions | None = None,
         lines_collection: LinesCollection | None = None,
         modules_collection: ModulesCollection | None = None,
     ) -> None:
@@ -154,7 +154,7 @@ class Visitor:
             extensions: The extensions to use when visiting.
             parent: An optional parent for the final module object.
             docstring_parser: The docstring parser to use.
-            docstring_options: The docstring parsing options.
+            docstring_options: Docstring parsing options.
             lines_collection: A collection of source code lines.
             modules_collection: A collection of modules.
         """
@@ -181,7 +181,7 @@ class Visitor:
         self.docstring_parser: DocstringStyle | Parser | None = docstring_parser
         """The docstring parser to use."""
 
-        self.docstring_options: dict[str, Any] = docstring_options or {}
+        self.docstring_options: DocstringOptions = docstring_options or {}
         """The docstring parsing options."""
 
         self.lines_collection: LinesCollection = lines_collection or LinesCollection()
@@ -288,6 +288,7 @@ class Visitor:
             docstring=self._get_docstring(node),
             lines_collection=self.lines_collection,
             modules_collection=self.modules_collection,
+            analysis="static",
         )
         self.extensions.call("on_instance", node=node, obj=module, agent=self)
         self.extensions.call("on_module_instance", node=node, mod=module, agent=self)
@@ -331,6 +332,7 @@ class Visitor:
             type_parameters=TypeParameters(*self._get_type_parameters(node, scope=node.name)),
             bases=bases,  # type: ignore[arg-type]
             runtime=not self.type_guarded,
+            analysis="static",
         )
         class_.labels |= self.decorators_to_labels(decorators)
 
@@ -427,6 +429,7 @@ class Visitor:
                 endlineno=node.end_lineno,
                 docstring=self._get_docstring(node),
                 runtime=not self.type_guarded,
+                analysis="static",
             )
             attribute.labels |= labels
             self.current.set_member(node.name, attribute)
@@ -460,6 +463,7 @@ class Visitor:
             docstring=self._get_docstring(node),
             runtime=not self.type_guarded,
             parent=self.current,
+            analysis="static",
         )
 
         property_function = self.get_base_property(decorators, function)
@@ -538,6 +542,7 @@ class Visitor:
                 type_parameters=TypeParameters(*self._get_type_parameters(node, scope=name)),
                 docstring=docstring,
                 parent=self.current,
+                analysis="static",
             )
             self.current.set_member(name, type_alias)
             self.extensions.call("on_instance", node=node, obj=type_alias, agent=self)
@@ -559,9 +564,10 @@ class Visitor:
                 lineno=node.lineno,
                 endlineno=node.end_lineno,
                 runtime=not self.type_guarded,
+                analysis="static",
             )
             self.current.set_member(alias_name, alias)
-            self.extensions.call("on_alias", alias=alias, node=node, agent=self)
+            self.extensions.call("on_alias_instance", alias=alias, node=node, agent=self)
 
     def visit_importfrom(self, node: ast.ImportFrom) -> None:
         """Visit an "import from" node.
@@ -594,9 +600,10 @@ class Visitor:
                     lineno=node.lineno,
                     endlineno=node.end_lineno,
                     runtime=not self.type_guarded,
+                    analysis="static",
                 )
                 self.current.set_member(alias_name, alias)
-                self.extensions.call("on_alias", alias=alias, node=node, agent=self)
+                self.extensions.call("on_alias_instance", alias=alias, node=node, agent=self)
 
     def handle_attribute(
         self,
@@ -646,7 +653,7 @@ class Visitor:
                 names = get_instance_names(node)
             except KeyError:  # Unsupported nodes, like subscript.
                 return
-            parent = parent.parent
+            parent = parent.parent  # type: ignore[assignment]
             if parent is None:
                 return
             labels.add("instance-attribute")
@@ -691,6 +698,7 @@ class Visitor:
                 endlineno=node.end_lineno,
                 docstring=docstring,
                 runtime=not self.type_guarded,
+                analysis="static",
             )
             attribute.labels |= labels
             parent.set_member(name, attribute)
