@@ -4,7 +4,8 @@ from __future__ import annotations
 
 import re
 from contextlib import suppress
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, TypedDict
+from warnings import warn
 
 from griffe._internal.docstrings.models import (
     DocstringAttribute,
@@ -198,6 +199,7 @@ def _read_parameters(
 
     block, new_offset = _read_block_items(docstring, offset=offset, warnings=warnings, **options)
 
+    # TODO: Use `get_name_annotation_description` here too?
     for line_number, param_lines in block:
         # Check the presence of a name and description, separated by a colon.
         try:
@@ -214,10 +216,10 @@ def _read_parameters(
         description = "\n".join([description.lstrip(), *param_lines[1:]]).rstrip("\n")
 
         # Use the type given after the parameter name, if any.
-        if " " in name_with_type:
-            name, annotation = name_with_type.split(" ", 1)
-            annotation = annotation.strip("()")
-            annotation = annotation.removesuffix(", optional")
+        if "(" in name_with_type and name_with_type.endswith(")"):
+            name, annotation = name_with_type.split("(", 1)
+            name = name.strip()
+            annotation = annotation.removesuffix(")").removesuffix(", optional").strip()
             # Try to compile the annotation to transform it into an expression.
             annotation = parse_docstring_annotation(annotation, docstring)
         else:
@@ -851,7 +853,30 @@ _section_reader = {
     DocstringSectionKind.receives: _read_receives_section,
 }
 
-_sentinel = object()
+
+class GoogleOptions(TypedDict, total=False):
+    """Options for parsing Google-style docstrings."""
+
+    ignore_init_summary: bool
+    """Whether to ignore the summary in `__init__` methods' docstrings."""
+    trim_doctest_flags: bool
+    """Whether to remove doctest flags from Python example blocks."""
+    returns_multiple_items: bool
+    """Whether to parse multiple items in `Yields` and `Returns` sections."""
+    returns_named_value: bool
+    """Whether to parse `Yields` and `Returns` section items as name and description, rather than type and description."""
+    returns_type_in_property_summary: bool
+    """Whether to parse the return type of properties at the beginning of their summary."""
+    receives_multiple_items: bool
+    """Whether to parse multiple items in `Receives` sections."""
+    receives_named_value: bool
+    """Whether to parse `Receives` section items as name and description, rather than type and description."""
+    warn_unknown_params: bool
+    """Whether to warn about unknown parameters."""
+    warn_missing_types: bool
+    """Whether to warn about missing types/annotations for parameters, return values, etc."""
+    warnings: bool
+    """Whether to issue warnings for parsing issues."""
 
 
 def parse_google(
@@ -867,6 +892,7 @@ def parse_google(
     warn_unknown_params: bool = True,
     warn_missing_types: bool = True,
     warnings: bool = True,
+    # YORE: Bump 2: Remove line.
     **options: Any,
 ) -> list[DocstringSection]:
     """Parse a Google-style docstring.
@@ -895,7 +921,7 @@ def parse_google(
         warn_unknown_params: Warn about documented parameters not appearing in the signature.
         warn_missing_types: Warn about missing types/annotations for parameters, return values, etc.
         warnings: Whether to log warnings at all.
-        **options: Additional parsing options.
+        **options: Swallowing keyword arguments for backward-compatibility.
 
     Returns:
         A list of docstring sections.
@@ -906,6 +932,10 @@ def parse_google(
     in_code_block = False
     lines = docstring.lines
 
+    # YORE: Bump 2: Remove block.
+    if options:
+        warn("Passing additional options is deprecated, these options are ignored.", DeprecationWarning, stacklevel=2)
+
     options = {
         "ignore_init_summary": ignore_init_summary,
         "trim_doctest_flags": trim_doctest_flags,
@@ -917,7 +947,6 @@ def parse_google(
         "warn_unknown_params": warn_unknown_params,
         "warn_missing_types": warn_missing_types,
         "warnings": warnings,
-        **options,
     }
 
     ignore_summary = (
